JsDoc Reference - ColReorder#dom

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:57:11 GMT-0000 (GMT)
HTML template: Codeview

# Namespace ColReorder#dom

Common and useful DOM elements for the class instance
Defined in: ColReorder.js.

Namespace Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| ColReorder#dom

Field Summary
Field Attributes | Field Name and Description
--- | ---
<static> | ColReorder#dom.drag Dragging element (the one the mouse is moving)
<static> | ColReorder#dom.pointer The insert cursor

Namespace Detail
ColReorder#dom
Field Detail
<static> {element} ColReorder#dom.drag
Dragging element (the one the mouse is moving)

Default Value:
  null

<static> {element} ColReorder#dom.pointer
The insert cursor

Default Value:
  null